@@ -5,15 +5,16 @@ from CPR import tools
 
 class ContributionRoom:
     """
-    This class manages contribution rooms for TFSA and RRSP.
+    This class manages contribution room for TFSAs and RRSPs.
+
     All amounts are nominal.
-    
+
     Parameters
     ----------
     init_room_rrsp: float
-        initial room available in rrsp
+        initial RRSP contribution room available
     init_room_tfsa: float
-        initial room available in tfsa
+        initial TFSA contribution room available
     """
     def __init__(self, init_room_rrsp, init_room_tfsa):
         self.init_room_rrsp = init_room_rrsp
@@ -22,7 +23,7 @@ class ContributionRoom:
 
     def compute_contributions(self, p, year, common, prices):
         """
-        Update contribution room for RRSP and TFSA
+        Function to update contribution room for RRSPs and TFSAs, using the 2 other functions below (which themselves call the other functions of the class).
 
         Parameters
         ----------
@@ -52,7 +53,7 @@ class ContributionRoom:
 
     def update_rrsp_room(self, p, year, common):
         """
-        Update RRSP contribution room.
+        Function to update RRSP contribution room.
 
         Parameters
         ----------
@@ -71,7 +72,7 @@ class ContributionRoom:
 
     def update_tfsa_room(self, p, year, common):
         """
-        Update TFSA contribution room.
+        Function to update TFSA contribution room.
 
         Parameters
         ----------
@@ -87,7 +88,7 @@ class ContributionRoom:
 
     def adjust_db_contributions(self, p, year, common):
         """
-        Adjust contributions room RRSP to DB RPP contribution.
+        Function to adjust RRSP contribution room to DB RPP contributions.
 
         Parameters
         ----------
@@ -109,8 +110,9 @@ class ContributionRoom:
 
     def adjust_dc_contributions(self, p, year):
         """
-        Adjust contribution room RRSP to DC contribution. If insufficent room,
-        extra contribution transferred to TFSA.
+        Function to adjust RRSP contribution room to DC RPP contributions.
+
+        If contribution room is insufficent for the intended/planned RRSP contributions, the "excess" contributions are channeled to TFSA.
 
         Parameters
         ----------
@@ -131,8 +133,7 @@ class ContributionRoom:
 
     def adjust_employees_contributions(self, p):
         """
-        Compute employee contribution to DC RPP
-        (used later to caculate taxes).
+        Function to compute employee contributions to DC RPPs (later used to caculate taxes).
 
         Parameters
         ----------
@@ -148,13 +149,14 @@ class ContributionRoom:
 
     def adjust_rrsp_contributions(self, acc, p, year):
         """
-        Adjust contribution room RRSP for contributions other than RPP.
-        If insufficent room, extra contribution transferred to TFSA.
+        Function to adjust RRSP contribution for contributions other than to RPPs.
+
+        If contribution room is insufficent for the intended/planned RRSP contributions, the "excess" contributions are channeled to TFSA.
 
         Parameters
         ----------
-        acc : [type]
-            [description]
+        acc : str
+            type of account
         p: Person
             instance of the class Person
         year : int
@@ -171,9 +173,9 @@ class ContributionRoom:
 
     def adjust_tfsa_contributions(self, p, year, common, prices):
         """
-        Adjust contribution room TFSA to TFSA contributions
-        and excess RRSP contributions. If insufficent room,
-        extra contribution transferred to TFSA.
+        Function to adjust TFSA contribution room to TFSA contributions (including "excess" DC RPP and RRSP contributions).
+
+        If contribution room is insufficent for the intended/planned TFSA contributions, the "excess" contributions are channeled to unregistered accounts.
 
         Parameters
         ----------
@@ -202,7 +204,7 @@ class ContributionRoom:
 
     def adjust_rrif(self, p, year, common, prices):
         """
-        Adjust RPP DC and RRSP to mandatory withdrawals.
+        Function to adjust DC RPP and RRSP accounts to mandatory RRIF withdrawals (RRIFs are not separately modelled in this version).
 
         Parameters
         ----------
@@ -217,8 +219,8 @@ class ContributionRoom:
 
         Returns
         -------
-        [type]
-            [description]
+        float
+            Nominal amount that needs to be withdrawn.
         """
         rrif_transfer_real = 0
         for acc in set(p.fin_assets) & set(('rpp_dc', 'rrsp', 'other_reg')):
@@ -227,8 +229,7 @@ class ContributionRoom:
 
     def adjust_unreg_contributions(self, p, year):
         """
-        Adjust contribution to unregistered accounts
-        for excess TFSA contributions.
+        Function to adjust contributions to unregistered accounts for "excess" TFSA contributions channeled to them.
 
         Parameters
         ----------
@@ -237,14 +238,13 @@ class ContributionRoom:
         year : int
             year
         """
-
         contrib = p.fin_assets['unreg'].contrib_rate * p.d_wages[year]
         contrib += self.extra_contrib_tfsa
         p.fin_assets['unreg'].contribution = contrib
 
     def reset(self):
         """
-        Reset contribution rooms RRSP and TFSA to inital values.
+        Reset RRSP and TFSA contribution rooms to their inital values.
         """
         self.room_rrsp = self.init_room_rrsp
         self.room_tfsa = self.init_room_tfsa
@@ -253,13 +253,15 @@ class ContributionRoom:
 class FinAsset:
     """
     This class manages registered accounts. All amounts are nominal.
-    
+
     Parameters
     ----------
     p: Person
-        spouse in household
+        instance of the class Person
     hh: Hhold
         household
+    acc: str
+        type of account
     """
     def __init__(self, p, hh, acc):
         self.init_balance = getattr(p, f'bal_{acc}')
@@ -273,7 +275,7 @@ class FinAsset:
 
     def update(self, d_returns, year, common, prices):
         """
-        Update the balance for contribution, withdrawal and return.
+        Function to update the balance to account for contributions, withdrawals, and returns.
 
         Parameters
         ----------
@@ -295,7 +297,7 @@ class FinAsset:
 
     def rate(self, d_returns, year):
         """
-        Compute the rate of return given the composition of assets in account.
+        Function to compute the rate of return given the mix of assets in the account.
 
         Parameters
         ----------
@@ -306,8 +308,8 @@ class FinAsset:
 
         Returns
         -------
-        [type]
-            [description]
+        float
+            Rate of return (net of fees).
         """
         return (self.mix_bills*d_returns['bills'][year]
                 + self.mix_bonds*d_returns['bonds'][year]
@@ -315,7 +317,7 @@ class FinAsset:
 
     def rrif_withdrawal(self, p, common):
         """
-        Manage mandatory rrif withdrawals.
+        Function to manage mandatory RRIF withdrawals.
 
         Parameters
         ----------
@@ -327,7 +329,7 @@ class FinAsset:
         Returns
         -------
         float
-            amount of mandatory withdrawal
+            Amount of mandatory withdrawal.
         """
         if self.balance > 0:
             extra_withdrawal_real = max(
@@ -341,12 +343,12 @@ class FinAsset:
 
     def liquidate(self):
         """
-        Liquidate account, set balance, contribution and withdrawal to zero.
-
+        Function to liquidate an account, setting balance, contributions and withdrawals to zero.
+        
         Returns
         -------
         float
-            amount from liquidation (before taxes)
+            Amount from liquidation (before taxes).
         """
         value = self.balance
         self.balance, self.contribution = 0, 0
@@ -363,12 +365,14 @@ class FinAsset:
 
 class UnregAsset:
     """
-    This class manages unregistered account. All amounts are nominal.
-    
+    This class manages unregistered accounts.
+
+    All amounts are nominal.
+
     Parameters
     ----------
     p: Person
-        spouse in household
+        instance of the class Person
     hh: Hhold
         household
     prices: Prices
@@ -390,11 +394,11 @@ class UnregAsset:
 
     def update(self, d_returns, year, common, prices):
         """
-        Update the balance for contribution, withdrawal and return.
+        Function to update the balance for contributions, withdrawals and returns.
 
         Parameters
         ----------
-        d_returns : dict
+        d_returns : dict of float
             dictionary of returns
         year : int
             year
@@ -416,11 +420,11 @@ class UnregAsset:
 
     def compute_income(self, d_returns, year):
         """
-        Compute new capital gains and taxable income (dividends and interests).
+        Function to compute new capital gains and taxable income (dividends and interests).
 
         Parameters
         ----------
-        d_returns : dict
+        d_returns : dict of float
             dictionary of returns
         year : int
             year
@@ -437,11 +441,11 @@ class UnregAsset:
 
     def rate(self, d_returns, year):
         """
-        Compute the rate of return given the composition of assets in account.
+        Function that computes the rate of return given the mix of assets in account.
 
         Parameters
         ----------
-        d_returns : dict
+        d_returns : dict of float
             dictionary of returns
         year : int
             year
@@ -449,7 +453,7 @@ class UnregAsset:
         Returns
         -------
         float
-            rate of return (net of fee)
+            Rate of return (net of fees).
         """
         return (self.mix_bills*d_returns['bills'][year] +
                 self.mix_bonds*d_returns['bonds'][year] +
@@ -457,8 +461,7 @@ class UnregAsset:
 
     def update_balance(self):
         """
-        Update balance and divide between non-taxable, capital gains,
-        dividends and interests.
+        Function to update to balance and separate between non-taxable funds (i.e. previous post-tax balance), capital gains, dividends, and interests.
         """
         self.non_taxable += self.amount_after_tax
         self.non_taxable += self.contribution
@@ -468,8 +471,7 @@ class UnregAsset:
 
     def prepare_withdrawal(self):
         """
-        Divide withdrawal from balance at the end of the period
-        between non-taxable, capital gains, dividends and interests.
+        Function to separate a withdrawal from the balance at the end of the period, and separately identify non-taxable funds, capital gains, dividends, and interests.
         """
         self.withdrawal = min(self.nom(self.desired_withdrawal), self.balance)
         self.share_withdrawal = self.withdrawal / (self.balance + 1e-12)
@@ -480,15 +482,15 @@ class UnregAsset:
 
     def adjust_income(self):
         """
-        Adjust income for withdrawals.
+        Function to adjust investment income (dividends and interests) for withdrawals.
         """
         self.inc_div *= 1 - self.share_withdrawal
         self.inc_int *= 1 - self.share_withdrawal
 
     def adjust_cap_losses(self, realized_cap_gains):
         """
-        Compute capital losses from previous years used for deduction
-        and adjust realized capital losses
+        Function to compute capital losses from previous years used for deduction 
+        against capital gains, and adjust realized capital losses accordingly.
 
         Parameters
         ----------
@@ -498,7 +500,7 @@ class UnregAsset:
         Returns
         -------
         float
-            capital losses (to be deducted)
+            Capital losses (to be deducted).
         """
         if realized_cap_gains > 0:
             used_cap_losses = min(realized_cap_gains, self.realized_losses)
@@ -511,7 +513,7 @@ class UnregAsset:
 
     def adjust_final_balance(self):
         """
-        Adjust final balance for withdrawal, dividends and interests.
+        Function that adjusts the final balance for withdrawals, dividends and interests.
         """
         self.non_taxable *= (1 - self.share_withdrawal)
         self.cap_gains *= (1 - self.share_withdrawal)
@@ -520,7 +522,7 @@ class UnregAsset:
 
     def liquidate(self):
         """
-        Liquidate account and adjust capital losses.
+        Function to liquidate the account and adjust capital losses.
         """
         self.liquidation_non_taxable = self.non_taxable
         self.liquidation_cap_gains = self.cap_gains
@@ -532,7 +534,7 @@ class UnregAsset:
 
     def reset(self):
         """
-        Reset the balance, cap_gains and withdrawal to its initial balance.
+        Function to reset the balance, capital gains, and withdrawals to their initial values.
         """
         self.balance = self.init_balance
         self.cap_gains = self.init_cap_gains
@@ -546,12 +548,14 @@ class UnregAsset:
 
 class RppDC(FinAsset):
     """
-    This class manages DC RPP. All amounts are nominal.
+    This class manages DC RPPs.
+
+    All amounts are nominal.
 
     Parameters
     ----------
     p: Person
-        spouse in household
+        instance of the class Person
     common: Common
         instance of the class Common
     """
@@ -568,12 +572,14 @@ class RppDC(FinAsset):
 
 class RppDB:
     """
-    This class manages DB RPP. All amounts are nominal.
-    
+    This class manages DB RPPs.
+
+    All amounts are nominal.
+
     Parameters
     ----------
     p: Person
-        spouse in household
+        instance of the class Person
     """
     def __init__(self, p):
         self.init_rate_employee_db = p.rate_employee_db
@@ -583,9 +589,9 @@ class RppDB:
 
     def compute_benefits(self, p, common):
         """
-        Compute RPP DB benefits and adjust them for CPP.
-        If RPP benefits are smaller than CPP benefits,
-        RPP benefits are zero when cpp_qpp starts.
+        Function that computes RPP DB benefits and adjusts them for CPP/QPP integration.
+
+        If RPP benefits are smaller than CPP/QPP benefits, RPP benefits are set to zero once the receipt of CPP/QPP retirement benefits begins.
 
         Parameters
         ----------
@@ -611,8 +617,9 @@ class RppDB:
 
     def adjust_for_penalty(self, p, common):
         """
-        DB RPP benefits lowered when less than 35 years of service and
-        retirement before age 62.
+        Function to compute a penalty for individuals who begin to receive DB RPP benefits "early", i.e. before they accumulate the maximum number of years of service, if they are younger than the age at which benefits can start without penalty (the "early retirement age").
+
+        By default, the penalty applies to those who begin RPP benefits receipt before reaching 35 years of service and before age 62. These values can be modified.
 
         Parameters
         ----------
@@ -636,9 +643,7 @@ class RppDB:
 
     def compute_cpp_adjustment(self, p, common):
         """
-        Compute adjustement to DB RPP for CPP benefits.
-        Start in base year if enough years until retirement, otherwise go
-        backward from year before retirement.
+        Function to compute an adjustment (reduction) to DB RPP benefits to account for CPP/QPP integration.
 
         Parameters
         ----------
@@ -650,7 +655,7 @@ class RppDB:
         Returns
         -------
         float
-            amount of CPP adjustment
+            Amount of benefit adjustment for CPP/QPP integration.
         """
         years_db = int(self.replacement_rate_db / common.perc_year_db)
 
@@ -668,7 +673,7 @@ class RppDB:
 
     def reset(self):
         """
-        Reset the benefits, cap_gains and withdrawal to its initial balance.
+        Function that resets the benefits and contribution rates to their initial values.
         """
         self.benefits = 0
         self.rate_employee_db = self.init_rate_employee_db
@@ -676,12 +681,14 @@ class RppDB:
 
 class RealAsset:
     """
-    This class manages housing. All amounts are nominal.
-    
+    This class manages housing and residences.
+
+    All amounts are nominal.
+
     Parameters
     ----------
     d_hh: dict of float
-        dictionnary containing values of residences
+        dictionary containing values of residences
     resid: str
         primary or secondary residence
     """
@@ -692,7 +699,7 @@ class RealAsset:
 
     def update(self, growth_rates, year, prices):
         """
-        Update the balance for growth in price.
+        Function to update the balance (residence values) for growth in price.
 
         Parameters
         ----------
@@ -707,12 +714,12 @@ class RealAsset:
 
     def liquidate(self):
         """
-        Liquidate account, compute capital gains, set balance to zero.
+        Function to liquidate the asset, compute capital gains if they apply, and set balance to zero.
 
         Returns
         -------
         float
-            amount from liquidation (before taxes)
+            Amount from asset liquidation (before taxes).
         """
         self.liquidation_non_taxable = self.price
         self.liquidation_cap_gains = self.balance - self.price
@@ -720,14 +727,14 @@ class RealAsset:
 
     def reset(self):
         """
-        Reset balance to its initial balance and set capital gains to zero.
+        Function to reset residence value to its initial value and set capital gains to zero.
         """
         self.balance = self.init_balance
         self.cap_gains = 0
 
     def impute_rent(self, hh, year, prices):
         """
-        Compute imputed rent.
+        Function to compute imputed rent.
 
         Parameters
         ----------
@@ -745,12 +752,13 @@ class RealAsset:
 class Business:
     """
     This class manages a business (as an asset owned by the houshehold).
+
     All amounts are nominal.
-    
+
     Parameters
     ----------
-    hh: Hhold
-        household
+    d_hh: dict of float
+        dictionary containing value of business
     """
     def __init__(self, d_hh):
         self.init_balance = d_hh['business']
@@ -759,12 +767,12 @@ class Business:
 
     def update(self, d_business_returns, year, prices):
         """
-        Update the balance and dividends.
+        Function to update the balance and dividends.
 
         Parameters
         ----------
         d_business_returns : dict
-            business returns
+            returns on business assets
         year : int
             year
         prices : Prices
@@ -775,8 +783,7 @@ class Business:
 
     def liquidate(self, common):
         """
-        Liquidate account, compute capital gains, set balance to zero
-        and returns real liquidation value.
+        Function to liquidate account (business assets), compute capital gains, and set balance to zero.
 
         Parameters
         ----------
@@ -786,7 +793,7 @@ class Business:
         Returns
         -------
         float
-            selling price
+            Selling price of the business assets.
         """
         self.liquidation_non_taxable = self.price
         self.liquidation_cap_gains = self.balance - self.price
@@ -794,7 +801,7 @@ class Business:
 
     def reset(self):
         """
-        Reset balance and capital gains to initial values.
+        Reset business value and capital gains to their initial values.
         """
         self.balance = self.init_balance
         self.cap_gains = self.init_balance - self.price
